#!/usr/bin/env python3
# Copyright (c) Facebook, Inc. and its affiliates.

from augly.video.composition import Compose, OneOf

from augly.video.functional import (
    add_noise,
    apply_lambda,
    audio_swap,
    blend_videos,
    blur,
    brightness,
    change_aspect_ratio,
    change_video_speed,
    color_jitter,
    concat,
    contrast,
    crop,
    encoding_quality,
    fps,
    grayscale,
    hflip,
    hstack,
    insert_in_background,
    loop,
    meme_format,
    overlay,
    overlay_dots,
    overlay_emoji,
    overlay_onto_screenshot,
    overlay_onto_background_video,
    overlay_shapes,
    overlay_text,
    pad,
    perspective_transform_and_shake,
    pixelization,
    remove_audio,
    replace_with_color_frames,
    resize,
    rotate,
    scale,
    shift,
    time_crop,
    time_decimate,
    trim,
    vflip,
    vstack,
)

from augly.video.transforms import (
    AddNoise,
    ApplyLambda,
    AudioSwap,
    BlendVideos,
    Blur,
    Brightness,
    ChangeAspectRatio,
    ChangeVideoSpeed,
    ColorJitter,
    Concat,
    Contrast,
    Crop,
    EncodingQuality,
    FPS,
    Grayscale,
    HFlip,
    HStack,
    InsertInBackground,
    Loop,
    MemeFormat,
    Overlay,
    OverlayDots,
    OverlayEmoji,
    OverlayOntoBackgroundVideo,
    OverlayOntoScreenshot,
    OverlayShapes,
    OverlayText,
    Pad,
    PerspectiveTransformAndShake,
    Pixelization,
    RandomAspectRatio,
    RandomBlur,
    RandomBrightness,
    RandomContrast,
    RandomEmojiOverlay,
    RandomEncodingQuality,
    RandomFPS,
    RandomNoise,
    RandomPixelization,
    RandomRotation,
    RandomVideoSpeed,
    RemoveAudio,
    ReplaceWithColorFrames,
    Resize,
    Rotate,
    Scale,
    Shift,
    TimeCrop,
    TimeDecimate,
    Trim,
    VFlip,
    VStack,
)

__all__ = [
    "AddNoise",
    "ApplyLambda",
    "AudioSwap",
    "BlendVideos",
    "Blur",
    "Brightness",
    "ChangeAspectRatio",
    "ChangeVideoSpeed",
    "ColorJitter",
    "Compose",
    "Concat",
    "Contrast",
    "Crop",
    "EncodingQuality",
    "FPS",
    "Grayscale",
    "HFlip",
    "HStack",
    "InsertInBackground",
    "Loop",
    "MemeFormat",
    "OneOf",
    "Overlay",
    "OverlayDots",
    "OverlayEmoji",
    "OverlayOntoBackgroundVideo",
    "OverlayOntoScreenshot",
    "OverlayShapes",
    "OverlayText",
    "Pad",
    "PerspectiveTransformAndShake",
    "Pixelization",
    "RandomAspectRatio",
    "RandomBlur",
    "RandomBrightness",
    "RandomContrast",
    "RandomEmojiOverlay",
    "RandomEncodingQuality",
    "RandomFPS",
    "RandomNoise",
    "RandomPixelization",
    "RandomRotation",
    "RandomVideoSpeed",
    "RemoveAudio",
    "ReplaceWithColorFrames",
    "Resize",
    "Rotate",
    "Scale",
    "Shift",
    "TimeCrop",
    "TimeDecimate",
    "Trim",
    "VFlip",
    "VStack",
    "add_noise",
    "apply_lambda",
    "audio_swap",
    "blend_videos",
    "blur",
    "brightness",
    "change_aspect_ratio",
    "change_video_speed",
    "color_jitter",
    "concat",
    "contrast",
    "crop",
    "encoding_quality",
    "fps",
    "grayscale",
    "hflip",
    "hstack",
    "insert_in_background",
    "loop",
    "meme_format",
    "overlay",
    "overlay_dots",
    "overlay_emoji",
    "overlay_onto_background_video",
    "overlay_onto_screenshot",
    "overlay_shapes",
    "overlay_text",
    "pad",
    "perspective_transform_and_shake",
    "pixelization",
    "remove_audio",
    "replace_with_color_frames",
    "resize",
    "rotate",
    "scale",
    "shift",
    "time_crop",
    "time_decimate",
    "trim",
    "vflip",
    "vstack",
]
